@@ -41,6 +41,7 @@
 # 26 Feb 2024 by Robin fix for user closing installer window prematurely by X in window border; added multilingual keyboard 4 level layout map
 # 13/28 Jul 2024 by Robin added compositor toggle, disk usage analyser
 # 08 Jul 2025 by Robin added hostname changer, memory manager.
+# 02 November 2025 by anticapitalista added antix-qogir and antix-kora icons
 #
 # Acknowledgements: Original script by KDulcimer of TinyMe. http://tinyme.mypclinuxos.com
 #################################################################################################################################################
@@ -62,15 +63,20 @@ fi
 #antix-papirus=papirus converted to png icons
 #antix-numix-bevel=numix-bevel png icons
 #antix-numix-square=numix square png icons
+#antix-qogir=qogir png icons
+#antix-kora=kora png icons
 
 #ICONS=/usr/share/icons/antix-moka
 #ICONS=/usr/share/icons/antix-faenza
-ICONS=/usr/share/icons/antix-papirus
+#ICONS=/usr/share/icons/antix-papirus
 #ICONS=/usr/share/icons/antix-numix-bevel
 #ICONS=/usr/share/icons/antix-numix-square
+#ICONS=/usr/share/icons/antix-kora
+ICONS=/usr/share/icons/antix-qogir
 ICONS2=/usr/share/pixmaps
 ICONS3=/usr/share/icons/papirus-antix/48x48/apps
 
+
 EXCLUDES_DIR=/usr/local/share/excludes 
 
 EDITOR="geany -i"
